==> seller-config-client-api-4.0.34-20220402.063117-4-sources.jar: com/xforceplus/seller/config/client/model/PersonTitleDto.java <==
package com.xforceplus.seller.config.client.model;

public class PersonTitleDto {

    private Long id;
    /**
     * 微信openId
     * 表 : cfg_3rd_personal_title
     * 对应字段 : wx_open_id
     */
    private String wxOpenId;

    /**
     * 支付宝userId
     * 表 : cfg_3rd_personal_title
     * 对应字段 : ali_user_id
     */
    private String aliUserId;

    /**
     * 1[企业] 2[个人]
     * 表 : cfg_3rd_personal_title
     * 对应字段 : buyer_title_type
     */
    private Integer buyerTitleType;

    /**
     *
     * 表 : cfg_3rd_personal_title
     * 对应字段 : buyer_company_name
     */
    private String buyerCompanyName;

    /**
     *
     * 表 : cfg_3rd_personal_title
     * 对应字段 : buyer_tax_no
     */
    private String buyerTaxNo;

    /**
     *
     * 表 : cfg_3rd_personal_title
     * 对应字段 : buyer_bank_name
     */
    private String buyerBankName;

    /**
     *
     * 表 : cfg_3rd_personal_title
     * 对应字段 : buyer_bank_no
     */
    private String buyerBankNo;

    /**
     *
     * 表 : cfg_3rd_personal_title
     * 对应字段 : buyer_address
     */
    private String buyerAddress;

    /**
     *
     * 表 : cfg_3rd_personal_title
     * 对应字段 : buyer_phone
     */
    private String buyerPhone;

    /**
     *
     * 表 : cfg_3rd_personal_title
     * 对应字段 : receive_phone
     */
    private String receivePhone;

    /**
     *
     * 表 : cfg_3rd_personal_title
     * 对应字段 : receive_mail
     */
    private String receiveMail;

    /**
     * 默认抬头
     * 表 : cfg_3rd_personal_title
     * 对应字段 : is_default
     */
    private Boolean isDefault;

    public String getWxOpenId() {
        return wxOpenId;
    }

    public void setWxOpenId(String wxOpenId) {
        this.wxOpenId = wxOpenId;
    }

    public String getAliUserId() {
        return aliUserId;
    }

    public void setAliUserId(String aliUserId) {
        this.aliUserId = aliUserId;
    }

    public Integer getBuyerTitleType() {
        return buyerTitleType;
    }

    public void setBuyerTitleType(Integer buyerTitleType) {
        this.buyerTitleType = buyerTitleType;
    }

    public String getBuyerCompanyName() {
        return buyerCompanyName;
    }

    public void setBuyerCompanyName(String buyerCompanyName) {
        this.buyerCompanyName = buyerCompanyName;
    }

    public String getBuyerTaxNo() {
        return buyerTaxNo;
    }

    public void setBuyerTaxNo(String buyerTaxNo) {
        this.buyerTaxNo = buyerTaxNo;
    }

    public String getBuyerBankName() {
        return buyerBankName;
    }

    public void setBuyerBankName(String buyerBankName) {
        this.buyerBankName = buyerBankName;
    }

    public String getBuyerBankNo() {
        return buyerBankNo;
    }

    public void setBuyerBankNo(String buyerBankNo) {
        this.buyerBankNo = buyerBankNo;
    }

    public String getBuyerAddress() {
        return buyerAddress;
    }

    public void setBuyerAddress(String buyerAddress) {
        this.buyerAddress = buyerAddress;
    }

    public String getBuyerPhone() {
        return buyerPhone;
    }

    public void setBuyerPhone(String buyerPhone) {
        this.buyerPhone = buyerPhone;
    }

    public String getReceivePhone() {
        return receivePhone;
    }

    public void setReceivePhone(String receivePhone) {
        this.receivePhone = receivePhone;
    }

    public String getReceiveMail() {
        return receiveMail;
    }

    public void setReceiveMail(String receiveMail) {
        this.receiveMail = receiveMail;
    }

    public Boolean getDefault() {
        return isDefault;
    }

    public void setDefault(Boolean aDefault) {
        isDefault = aDefault;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }
}

==> seller-config-client-api-4.1.30-20250928.033323-2-sources.jar: com/xforceplus/seller/config/client/model/PersonTitleDto.java <==
package com.xforceplus.seller.config.client.model;

public class PersonTitleDto {

    private Long id;
    /**
     * 微信openId
     * 表 : cfg_3rd_personal_title
     * 对应字段 : wx_open_id
     */
    private String wxOpenId;

    /**
     * 支付宝userId
     * 表 : cfg_3rd_personal_title
     * 对应字段 : ali_user_id
     */
    private String aliUserId;

    /**
     * 1[企业] 2[个人]
     * 表 : cfg_3rd_personal_title
     * 对应字段 : buyer_title_type
     */
    private Integer buyerTitleType;

    /**
     *
     * 表 : cfg_3rd_personal_title
     * 对应字段 : buyer_company_name
     */
    private String buyerCompanyName;

    /**
     *
     * 表 : cfg_3rd_personal_title
     * 对应字段 : buyer_tax_no
     */
    private String buyerTaxNo;

    /**
     *
     * 表 : cfg_3rd_personal_title
     * 对应字段 : buyer_bank_name
     */
    private String buyerBankName;

    /**
     *
     * 表 : cfg_3rd_personal_title
     * 对应字段 : buyer_bank_no
     */
    private String buyerBankNo;

    /**
     *
     * 表 : cfg_3rd_personal_title
     * 对应字段 : buyer_address
     */
    private String buyerAddress;

    /**
     *
     * 表 : cfg_3rd_personal_title
     * 对应字段 : buyer_phone
     */
    private String buyerPhone;

    /**
     *
     * 表 : cfg_3rd_personal_title
     * 对应字段 : receive_phone
     */
    private String receivePhone;

    /**
     *
     * 表 : cfg_3rd_personal_title
     * 对应字段 : receive_mail
     */
    private String receiveMail;

    /**
     * 默认抬头
     * 表 : cfg_3rd_personal_title
     * 对应字段 : is_default
     */
    private Boolean isDefault;

    private Boolean isDeleted = false;

    public String getWxOpenId() {
        return wxOpenId;
    }

    public void setWxOpenId(String wxOpenId) {
        this.wxOpenId = wxOpenId;
    }

    public String getAliUserId() {
        return aliUserId;
    }

    public void setAliUserId(String aliUserId) {
        this.aliUserId = aliUserId;
    }

    public Integer getBuyerTitleType() {
        return buyerTitleType;
    }

    public void setBuyerTitleType(Integer buyerTitleType) {
        this.buyerTitleType = buyerTitleType;
    }

    public String getBuyerCompanyName() {
        return buyerCompanyName;
    }

    public void setBuyerCompanyName(String buyerCompanyName) {
        this.buyerCompanyName = buyerCompanyName;
    }

    public String getBuyerTaxNo() {
        return buyerTaxNo;
    }

    public void setBuyerTaxNo(String buyerTaxNo) {
        this.buyerTaxNo = buyerTaxNo;
    }

    public String getBuyerBankName() {
        return buyerBankName;
    }

    public void setBuyerBankName(String buyerBankName) {
        this.buyerBankName = buyerBankName;
    }

    public String getBuyerBankNo() {
        return buyerBankNo;
    }

    public void setBuyerBankNo(String buyerBankNo) {
        this.buyerBankNo = buyerBankNo;
    }

    public String getBuyerAddress() {
        return buyerAddress;
    }

    public void setBuyerAddress(String buyerAddress) {
        this.buyerAddress = buyerAddress;
    }

    public String getBuyerPhone() {
        return buyerPhone;
    }

    public void setBuyerPhone(String buyerPhone) {
        this.buyerPhone = buyerPhone;
    }

    public String getReceivePhone() {
        return receivePhone;
    }

    public void setReceivePhone(String receivePhone) {
        this.receivePhone = receivePhone;
    }

    public String getReceiveMail() {
        return receiveMail;
    }

    public void setReceiveMail(String receiveMail) {
        this.receiveMail = receiveMail;
    }

    public Boolean getDefault() {
        return isDefault;
    }

    public void setDefault(Boolean aDefault) {
        isDefault = aDefault;
    }

    public Boolean getIsDefault() {
        return isDefault;
    }

    public void setIsDefault(Boolean isDefault) {
        this.isDefault = isDefault;
    }

    public Boolean getIsDeleted() {
        return isDeleted;
    }

    public void setIsDeleted(Boolean isDeleted) {
        this.isDeleted = isDeleted;
    }
    public Boolean getDeleted() {
        return isDeleted;
    }

    public void setDeleted(Boolean isDeleted) {
        this.isDeleted = isDeleted;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }
}
